package com.syc.slm.slmbi.controller;

import com.google.common.collect.Maps;
import com.google.gson.reflect.TypeToken;
import com.syc.slm.common.core.constant.SlmConstants;
import com.syc.slm.common.core.util.NetResponseUtils;
import com.syc.slm.common.core.util.R;
import com.syc.slm.common.core.util.RestTemplateUtils;
import com.syc.slm.slmbi.entity.CurrentUser;
import com.syc.slm.slmbi.exception.SysException;
import com.syc.slm.slmbi.function.Action0;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.context.request.NativeWebRequest;
import org.springframework.web.context.request.RequestAttributes;
import org.springframework.web.context.request.ServletWebRequest;
import org.springframework.web.servlet.HandlerMapping;
import org.springframework.web.servlet.View;

import javax.servlet.http.HttpServletRequest;
import java.util.Enumeration;
import java.util.Map;
import java.util.function.Supplier;

/**
 * slm-bi
 * 抽取公用得controller父类
 *
 * @author : lin
 * @date : 2021-04-06 09:09
 **/
@Slf4j

public class BaseRestController {


    /**
     * 用户token
     */
    protected String token;

    /**
     * 用户信息
     */
    protected  CurrentUser currentUser;
    @Value("${dc_client.host}")
    protected String dcClientHost;
    @Value("${dc_client.interfaces.positionListUrl}")
    protected String positionListUrl;
    @Value("${dc_client.interfaces.deptListUrl}")
    protected String deptListUrl;
    @Value("${dc_client.interfaces.userTree}")
    protected String userTree;
    @Value("${dc_client.interfaces.variableList}")
    protected String variableList;
    @Value("${dc_client.interfaces.deviceList}")
    protected String deviceList;

    @Value("${dc_client.interfaces.deptsRoles}")
    protected String deptsRoles;





    @ModelAttribute
    public void onInit(HttpServletRequest request) {
        String uri = request.getRequestURI();
        log.info("请求url--->>>>" + uri);
        Map<String, String[]> parameterMap = request.getParameterMap();
        log.info("请求参数--->>>>"+SlmConstants.gson.toJson(parameterMap));
        Enumeration<String> headerNames = request.getHeaderNames();
        Map<String,String> headers = Maps.newHashMap();
        while (headerNames.hasMoreElements()){
            String headerName = headerNames.nextElement();
            Enumeration<String> headerValues = request.getHeaders(headerName);
            while(headerValues.hasMoreElements()){
                headers.put(headerName, headerValues.nextElement());
            }
        }
        log.info("请求头参数--->>>>"+SlmConstants.gson.toJson(headers));
        token=request.getHeader("token");
        if(StringUtils.isEmpty(token)){
            throw new SysException("token不能为空");
        }
        log.info("获取用户信息");
        NativeWebRequest webRequest = new ServletWebRequest(request);
        Map<String, String> map = (Map<String, String>) webRequest.getAttribute(HandlerMapping.URI_TEMPLATE_VARIABLES_ATTRIBUTE, RequestAttributes.SCOPE_REQUEST);
       // Map<String, Object> map = (Map<String, Object>) webRequest.getAttribute(View.PATH_VARIABLES, RequestAttributes.SCOPE_REQUEST);
        Map<String,String> heads = Maps.newHashMap();
        heads.put("token",token);
        Map<String,String> uriVariables =Maps.newHashMap();
        uriVariables.put("appId",map.get("appId")+"");
        String getUrl =dcClientHost+"/{appId}/users/user-info";
        R<Map<String,Object>> result = RestTemplateUtils.get(getUrl, heads, new TypeToken<R<Map<String,Object>>>() {}.getType(), uriVariables);
        Map<String,Object> userInfo= result.detach();
        currentUser = new CurrentUser();
        currentUser.setUid(userInfo.get("uid")+"");
        currentUser.setPlatformId(userInfo.get("platform_id")+"");
        currentUser.setName(userInfo.get("real_name")+"");
        currentUser.setAppId(userInfo.get("app_id")+"");
        currentUser.setToken(token);
        request.getSession().setAttribute(token, SlmConstants.gson.toJson(currentUser));

    }
    R<Object> call(Action0 action) {
        return NetResponseUtils.call(action);
    }

    <T> R<T> call(Supplier<T> supplier) {
        return NetResponseUtils.call(supplier);
    }
}
