package com.syc.slm.slmbi.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.syc.slm.common.core.util.R;
import com.syc.slm.slmbi.dto.SaveInstrumentPanelDTO;
import com.syc.slm.slmbi.dto.QueryInstrumentPanelDTO;
import com.syc.slm.slmbi.service.InstrumentPanelService;
import com.syc.slm.slmbi.vo.InstrumentPanelConfigVo;
import com.syc.slm.slmbi.vo.InstrumentPanelVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.Arrays;
import java.util.List;

/**
 * slm-bi
 * 仪表板
 *
 * @author : lin
 * @date : 2021-03-25 15:10
 **/
@RestController
@RequestMapping("/{appId}/panels")
@Api(value = "仪表板配置接口", tags = "仪表板配置接口")
public class InstrumentPanelController extends BaseRestController {

    @Autowired
    private InstrumentPanelService instrumentPanelService;

    /**
     * where :{name:'',creator:'',updater:'',startDate:'' ,endDate:'',recordStatus:''}
     *
     * @param where
     * @return
     */
    @GetMapping
    @ApiOperation("仪表板列表")
    @ApiImplicitParam(name = "appId", value = "租户id", required = true, dataTypeClass = String.class)
    public R<IPage<InstrumentPanelVo>> selectInstrumentPanelList(@PathVariable String appId,
        QueryInstrumentPanelDTO where) {
        return call(() -> instrumentPanelService.selectInstrumentPanelList(appId, where));
    }

    @PostMapping
    @ApiOperation("新增仪表板")
    @ApiImplicitParam(name = "appId", value = "租户id", required = true, dataTypeClass = String.class)
    public R<String> saveInstrumentPanel(@PathVariable String appId, @RequestBody SaveInstrumentPanelDTO panel) {
        return call(() -> instrumentPanelService.savePanel(appId, panel));
    }

    @PutMapping("/publish")
    @ApiOperation("批量发布")
    @ApiImplicitParams({@ApiImplicitParam(name = "ids",
        value = "仪表板id集合",
        required = true,
        dataTypeClass = Arrays.class),
        @ApiImplicitParam(name = "appId", value = "租户id", required = true, dataTypeClass = String.class)})
    public R<List<String>> batchPublish(@PathVariable String appId, @RequestParam  List<String> ids) {
        return call(() -> instrumentPanelService.batchPublish(ids));
    }

    @PutMapping("/{id}/offline")
    @ApiOperation("下线")
    @ApiImplicitParams({@ApiImplicitParam(name = "id", value = "仪表板id", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(name = "appId", value = "租户id", required = true, dataTypeClass = String.class)})
    public R<String> offline(@PathVariable String appId, @PathVariable("id") String id) {
        return call(() -> instrumentPanelService.offline(id));
    }

    @DeleteMapping("/{id}")
    @ApiOperation("删除仪表板")
    @ApiImplicitParams({@ApiImplicitParam(name = "id", value = "仪表板id", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(name = "appId", value = "租户id", required = true, dataTypeClass = String.class)})
    public R<String> delInstrumentPanel(@PathVariable String appId, @PathVariable("id") String id) {
        return call(() -> instrumentPanelService.delPanel(id));
    }

    @PostMapping("/save-as")
    @ApiOperation("另存为")
    @ApiImplicitParam(name = "id", value = "仪表板id", required = true, dataTypeClass = String.class)
    public R<String> saveAs(@PathVariable String appId, @RequestBody SaveInstrumentPanelDTO panelDTO) {
        return call(() -> instrumentPanelService.saveAsPanel(appId, panelDTO));
    }

    @PostMapping("/{id}/show-recovery-btn")
    @ApiOperation("是否显示恢复按钮")
    @ApiImplicitParams({@ApiImplicitParam(name = "id", value = "仪表板id", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(name = "appId", value = "租户id", required = true, dataTypeClass = String.class)})
    public R<Boolean> showRecoveryBtn(@PathVariable String appId, @PathVariable("id") String id) {
        return call(() -> instrumentPanelService.showRecoveryBtn(id));
    }

    @PutMapping("/{id}/recovery")
    @ApiOperation("恢复按钮操作")
    @ApiImplicitParams({@ApiImplicitParam(name = "id", value = "仪表板id", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(name = "appId", value = "租户id", required = true, dataTypeClass = String.class)})
    public R<InstrumentPanelConfigVo> recoveryInstrumentPanel(@PathVariable String appId, @PathVariable("id") String id) {
        return call(() -> instrumentPanelService.recoveryPanel(id));
    }

}
