package com.syc.slm.slmbi.controller;

import com.syc.slm.common.core.util.R;
import com.syc.slm.slmbi.dto.InstrumentPanelPermissionDTO;
import com.syc.slm.slmbi.service.InstrumentPanelPermissionService;
import com.syc.slm.slmbi.vo.InstrumentPanelPermissionVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.Arrays;
import java.util.List;

/**
 * slm-bi
 * 仪表板权限控制
 *
 * @author : lin
 * @date : 2021-03-25 18:54
 **/
@Api(value = "仪表板权限控制", tags = "仪表板权限控制")
@RestController
@RequestMapping("/{appId}/panel-permissions")
public class InstrumentPanelPermissionController extends BaseRestController {

    @Autowired
    private InstrumentPanelPermissionService instrumentPanelPermissionService;

    @PostMapping
    @ApiOperation("保存仪表板权限（列表的属性保存）")
    @ApiImplicitParam(name = "appId", value = "租户id", required = true, dataTypeClass = String.class)
    public R<String> savePermission(@PathVariable String appId, @RequestBody InstrumentPanelPermissionDTO permission) {
        return call(() -> instrumentPanelPermissionService.savePermission(permission));
    }

    @GetMapping("/{panelId}/to-copy")
    @ApiOperation("从其他仪表板复制配置")
    @ApiImplicitParams({@ApiImplicitParam(name = "appId",
        value = "租户id",
        required = true,
        dataTypeClass = String.class),
        @ApiImplicitParam(name = "panelId", value = "其他仪表板id", required = true, dataTypeClass = String.class)})
    public R<InstrumentPanelPermissionVo> saveCopyOtherPermission(@PathVariable String appId,
        @PathVariable String panelId) {
        return call(() -> (instrumentPanelPermissionService.saveCopyOtherPermission(panelId)));
    }

    @PostMapping("/copy-to")
    @ApiOperation("将仪表板权限复制给其他仪表板")
    @ApiImplicitParams({@ApiImplicitParam(name = "appId",
        value = "租户id",
        required = true,
        dataTypeClass = String.class),
        @ApiImplicitParam(name = "panelIds", value = "其他仪表板id", required = true, dataTypeClass = Arrays.class)})
    public R<Object> saveCopyToOtherPermission(@PathVariable String appId,
        @RequestBody InstrumentPanelPermissionDTO permission,
        @RequestParam List<String> panelIds) {
        return call(() -> instrumentPanelPermissionService.saveCopyToOtherPermission(permission, panelIds));
    }

    @GetMapping("/{panelId}")
    @ApiOperation("根据仪表板id获取仪表板权限")
    @ApiImplicitParams({@ApiImplicitParam(name = "appId",
        value = "租户id",
        required = true,
        dataTypeClass = String.class),
        @ApiImplicitParam(name = "panelId", value = "其他仪表板id", required = true, dataTypeClass = String.class)})
    public R<InstrumentPanelPermissionVo> selectPermissionByPanelId(@PathVariable String appId,
        @PathVariable String panelId) {
        return call(() -> (instrumentPanelPermissionService.selectPermissionByPanelId(panelId)));
    }
}
