package com.syc.slm.slmbi.exception;

import com.syc.slm.common.core.constant.CommonConstants;
import com.syc.slm.common.core.constant.SlmConstants;
import org.apache.commons.lang3.StringUtils;

import java.io.ByteArrayOutputStream;
import java.io.PrintWriter;

/**
 * slm-bi
 * 业务异常类
 *
 * @author : lin
 * @date : 2021-04-06 09:14
 **/
public class SysException extends RuntimeException {
    private int code;
    private String msg;
    private Object data;
    private String debugMsg;

    public int getCode() {
        return code;
    }

    public String getMsg() {
        return msg;
    }

    public Object getData() {
        return data;
    }

    public String getDebugMsg() {
        return debugMsg;
    }

    public SysException(String msg) {
        this(msg, null, null);
    }

    public SysException(String msg, String debugInfo) {
        this.msg = msg;
        this.debugMsg = debugInfo;
        this.code = CommonConstants.FAIL;
    }

    public SysException(String msg, Exception originalException) {
        this(msg, originalException, null);
    }

    private SysException(String msg, Exception originalException, Object pData) {
        super(msg);
        code = CommonConstants.FAIL;
        this.msg = msg;
        data = pData;
        if (originalException != null) {
            ByteArrayOutputStream outputStream = new ByteArrayOutputStream();
            PrintWriter writer = new PrintWriter(outputStream);
            originalException.printStackTrace(writer);
            debugMsg = new String(outputStream.toByteArray());
        }
    }

    public SysException(int dwCode, String szMsg) {
        this(dwCode, szMsg, null);
    }

    private SysException(int dwCode, String szMsg, Exception originalException) {
        super(szMsg);
        code = dwCode;
        msg = szMsg;
        if (originalException != null) {
            ByteArrayOutputStream outputStream = new ByteArrayOutputStream();
            PrintWriter writer = new PrintWriter(outputStream);
            originalException.printStackTrace(writer);
            debugMsg = new String(outputStream.toByteArray());
        }
    }

    @Override
    public String toString() {
        if (StringUtils.isNotEmpty(msg)) {
            return msg;
        }
        if (StringUtils.isNotEmpty(debugMsg)) {
            return debugMsg;
        }
        if (data != null) {
            return SlmConstants.gson.toJson(data);
        }
        return code + "";
    }

}
