package com.syc.slm.slmbi.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.syc.slm.slmbi.dto.InstrumentPanelConfigDTO;
import com.syc.slm.slmbi.entity.InstrumentPanelConfig;
import com.syc.slm.slmbi.vo.InstrumentPanelConfigVo;

import javax.validation.constraints.NotNull;
import java.util.List;
import java.util.Map;

/**
 * slm-bi
 * 仪表板配置
 *
 * @author : lin
 * @date : 2021-03-25 15:10
 **/
public interface InstrumentPanelConfigService extends IService<InstrumentPanelConfig>{


    /**
     * 根据仪表板id获取对应已发布配置
     * @param instrumentPanelId
     * @return
     */
    InstrumentPanelConfigVo getPublishConfigByPanelId(@NotNull String instrumentPanelId);

    /**
     * 根据仪表板id获取对应配置
     * @param instrumentPanelId
     * @return
     */
    InstrumentPanelConfigVo getConfigByPanelId(@NotNull String instrumentPanelId);

    /**
     * 保存发布仪表板配置
     * @param appId
     * @param config
     * @return
     */
    String publish(String appId,InstrumentPanelConfigDTO config);

    /**
     * 保存仪表板配置
     * @param appId
     * @param config
     * @return
     */
    String saveConfig(String appId,InstrumentPanelConfigDTO config);

    /**
     * 根据仪表板id删除仪表板配置
     * @param panelId
     * @param publishedStatus
     */
    void delConfig(@NotNull String panelId,String publishedStatus);

    /**
     * 根据仪表板详情保存仪表盘配置
     * @param panelId
     * @param configDetails
     * @param publishStatus
     */
    void savePanelConfig(String panelId,String configDetails,String publishStatus);

    /**
     * 发布仪表板把对应配置状态修改为发布
     * @param ids
     */
    void publishConfigByPanelIds(List<String> ids);

    /**
     * 根据仪表板id以及状态获取仪表板配置
     * @param panelId
     * @param publishStatus
     * @return
     */
    List<InstrumentPanelConfig> getConfigByPanelIdAndPublishStatus(String panelId,String publishStatus);

    /**
     * 下线仪表盘配置
     * @param panelId
     * @param publishStatus
     */
    void offlineConfig(String panelId, String publishStatus);

    /**
     * 根据仪表id获取仪表板配置
     * @param panelId
     */
    Map<String,String> getAssemblyConfig(@NotNull String panelId);
}
