package com.syc.slm.slmbi.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.syc.slm.slmbi.dto.CustomPermissionDTO;
import com.syc.slm.slmbi.dto.InstrumentPanelPermissionDTO;
import com.syc.slm.slmbi.entity.InstrumentPanelPermission;
import com.syc.slm.slmbi.vo.CustomPermissionVo;
import com.syc.slm.slmbi.vo.InstrumentPanelPermissionVo;
import lombok.NonNull;

import java.util.List;
/**
 * slm-bi
 * 仪表板权限控制
 *
 * @author : lin
 * @date : 2021-03-25 18:54
 **/
public interface InstrumentPanelPermissionService extends IService<InstrumentPanelPermission> {
    /**
     * 保存仪表板权限
     *
     * @param permissions
     * @return
     */
    String savePermission(InstrumentPanelPermissionDTO permissions);

    /**
     * 从其他仪表板复制配置
     *
     * @param instrumentPanelId
     * @return
     */
    InstrumentPanelPermissionVo saveCopyOtherPermission(@NonNull String instrumentPanelId);

    /**
     * 将仪表板权限复制给其他仪表板
     *
     * @param permissions
     * @param otherInstrumentPanelIds
     * @return
     */
    void saveCopyToOtherPermission(InstrumentPanelPermissionDTO permissions, List<String> otherInstrumentPanelIds);

    /**
     * 根据仪表板id获取仪表板权限
     *
     * @param instrumentPanelId
     * @return
     */
    InstrumentPanelPermissionVo selectPermissionByPanelId(@NonNull String instrumentPanelId);

    /**
     * 根据仪表板id删除仪表板权限
     * @param panelId
     * @param publishStatus
     */
    void delPermissionByPanelId(@NonNull String panelId,String publishStatus);

    /**
     * 根据仪表板id获取已经发布的配置
     * @param panelId
     * @param publishStatus
     * @return
     */
    List<CustomPermissionVo> getPublishPermissionByPanelId(@NonNull String panelId,@NonNull String publishStatus);

    /**
     * 根据仪表板详情保存仪表板配置
     * @param customPermissions
     * @param panelId
     * @param accessType
     * @param publishStatus
     */
    void savePanelPermission(List<CustomPermissionDTO> customPermissions,String panelId,String accessType,String publishStatus);

    /**
     * 批量发布把对应配置状态更改为发布状态
     * @param ids
     */
    void publishPermissionByPanelIds(List<String> ids);

    /**
     * 根据仪表板id 以及 状态获取仪表板对应权限
     * @param panelId
     * @param publishStatus
     * @return
     */
    List<InstrumentPanelPermission> getPermissionByPanelIdAndPublishStatus(String panelId, String publishStatus);

    /**
     * 下线仪表板对应权限
     * @param panelId
     */
    void offlinePermission(String panelId);
}
